@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -159,24 +159,28 @@ public class TransportHandler {
             httpURLConnection.setRequestProperty("Proxy-Authorization", proxyAutorizationProperty);
         }
 
+        DataOutputStream stream = null;
         try {
-            final DataOutputStream stream = new DataOutputStream(httpURLConnection.getOutputStream());
+            stream = new DataOutputStream(httpURLConnection.getOutputStream());
             stream.writeBytes(report.toString());
             if (metadata.getBoolean("needsComposition")) {
                 appendStoredContentToOutputstream(metadata, stream, true);
             }
             stream.flush();
             stream.close();
+            stream = null;
         } catch (SSLException e) {
             e.printStackTrace();
-            System.err.println("Report sending failure, unable to send with ssl.");
+            System.err.println("Report sending failure, unable to send with SSL.");
             if (isHttps) {
-                System.out.println("Trying to send without ssl.");
+                System.out.println("Trying to send without SSL.");
                 sendReport(false, reportConfiguration, metadata);
                 return;
             } else {
                 saveReportToHardDrive(metadata);
             }
+        } finally {
+            Streams.close(stream);
         }
 
         if (httpURLConnection.getResponseCode() != HttpURLConnection.HTTP_OK) {
